package com.puship.test;

import java.net.UnknownHostException;
import java.util.Calendar;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Set;

import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.json.JSONArray;
import org.json.JSONObject;

import com.puship.CoreApi;
import com.puship.Credentials;
import com.puship.PushipUtil;

public class Sample {

	protected Shell shlSampleForm;
	private Text text;
	private Button btnGetPushMessages;
	private Button btnGetPushMessagesByDevice;
	private Button btnDeletePushMessage;
	private Button btnSendPushMessage;
	private Button btnSendPushMessageByDevice;

	/**
	 * Launch the application.
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			Sample window = new Sample();
			window.open();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Open the window.
	 */
	public void open() {
		Display display = Display.getDefault();
		createContents();
		shlSampleForm.open();
		shlSampleForm.layout();
		while (!shlSampleForm.isDisposed()) {
			if (!display.readAndDispatch()) {
				display.sleep();
			}
		}
	}

	/**
	 * Create contents of the window.
	 */
	protected void createContents() {
		shlSampleForm = new Shell(shlSampleForm, SWT.SHELL_TRIM & (~SWT.RESIZE));
		shlSampleForm.setSize(831, 539);
		shlSampleForm.setText("SAMPLE FORM");
		
		text = new Text(shlSampleForm, SWT.BORDER | SWT.READ_ONLY | SWT.WRAP | SWT.H_SCROLL | SWT.V_SCROLL | SWT.CANCEL);
		text.setEditable(false);
		text.setBounds(188, 10, 617, 480);
		
		Button btnGetDevices = new Button(shlSampleForm, SWT.NONE);
		btnGetDevices.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				
				Credentials cr= new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca= new CoreApi(ConfigClass.AppId , cr);
				//ca.EnableDebug = true; //Shows Url, Url Parameters, Response Code, and the Response from the Server
				
				PushipUtil.SetTimeZone("Europe");
				
				try {
					
					HashMap<String, Object> map= new HashMap<String, Object>();
					
					map.put("DeviceType", "3"); //Android platform filter
					map.put("Limit", "10");
					map.put("Offset", "0");
					
				    /*map.put("P1Latitude", "40.42163694648697");
					map.put("P1Longitude", "10.299156188964844");
					map.put("P2Latitude", "47.45030563100575");
					map.put("P2Longitude", "15.368927001953125");*/
					
					map.put("Expired", "True");

					Calendar c = Calendar.getInstance();
					c.set(2014, 5, 6, 0, 0,0); // June, 07, 2014
					
					/*map.put("LastPositionDate", c.getTime());
					map.put("LastPositionNumber", "1");*/
					
					Set<String> tagmaps = new HashSet<String>();
					tagmaps.add("Libra"); //Tag number 1
					tagmaps.add("Virgo"); //Tag number 2
				
					map.put("Tags", tagmaps);
					
					JSONArray al= ca.GetDevices(map); //returns devices depending by filters
					//JSONArray al= ca.GetDevices();  //returns all devices
					
					text.append("\r\nGet Devices \r\n");
					if (al!=null){
						for (int i = 0; i < al.length(); i++) {
							text.append(al.getJSONObject(i).get("DeviceId") + "\r\n" );
							text.append(al.getJSONObject(i).get("Expired") + "\r\n");
							text.append(al.getJSONObject(i).get("DeviceType") + "\r\n");
							
							String created = al.getJSONObject(i).getString("Created");
							text.append(PushipUtil.ParseDate(created) + "\r\n");
							String updated = al.getJSONObject(i).getString("Updated");
							text.append(PushipUtil.ParseDate(updated) + "\r\n");
						}
					} else{
						text.append("Error during request \r\n");
					}
					 
				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during GetDevices \r\n");
				}
			}
		});
		
		btnGetDevices.setBounds(10, 10, 172, 25);
		btnGetDevices.setText("Get Devices");
		
		Button btnGetTags = new Button(shlSampleForm, SWT.NONE);
		
		btnGetTags.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca = new CoreApi(ConfigClass.AppId, cr);

				try {

					HashMap<String, Object> map = new HashMap<String, Object>();
					map.put("ReturnHistory", "True");	//If true, returns even the filters used in the past but not associated with any device at the moment (default false)

					JSONArray al = ca.GetAppTagFilters(map);
					
					text.append("\r\nGet App Tags Filters \r\n");
					if (al != null) {
						for (int i = 0; i < al.length(); i++) {
							text.append(al.get(i) + "\r\n");
						}
					} else {
						text.append("Error during request \r\n");
					}

				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during GetAppTagFilters \r\n");
				}
			}
		});
		
		btnGetTags.setBounds(10, 41, 172, 25);
		btnGetTags.setText("Get Tags");
		
		btnGetPushMessages = new Button(shlSampleForm, SWT.NONE);
		
		btnGetPushMessages.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				
				Credentials cr= new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca= new CoreApi(ConfigClass.AppId , cr);
				
				try {
					
					HashMap<String, Object> map= new HashMap<String, Object>();
					map.put("DeviceType", "1"); //Apple Platform filter 
					map.put("Limit", "10");
					map.put("Offset", "0");
					map.put("IncludeParams", "True");

				   // map.put("Latitude", "45.44085");
					//map.put("Longitude", "12.31552");
					
					Calendar c = Calendar.getInstance();
					c.set(2014, 5, 6, 0, 0,0); // June, 07, 2014
					
					map.put("LastPositionDate", c.getTime());
					map.put("LastPositionNumber", "1");

					Set<String> tagmaps = new HashSet<String>();
					
					tagmaps.add("Libra"); //Tag number 1
					tagmaps.add("Virgo"); //Tag number 2
					
					map.put("Tags", tagmaps);
					
					JSONArray al= ca.GetPushMessages(map); 
					
					text.append("\r\nGet Push Messages \r\n");
					if (al!=null){
						for (int i = 0; i < al.length(); i++) {
							text.append(al.getJSONObject(i).get("PushMessageId") + "\r\n");
							text.append(al.getJSONObject(i).get("Message") + "\r\n");
							
							String date= al.getJSONObject(i).getString("Date");
							text.append(PushipUtil.ParseDate(date) + "\r\n");

							text.append(al.getJSONObject(i).getJSONObject("Params").get("Param1") + "\r\n");
							text.append(al.getJSONObject(i).getJSONObject("Params").get("Param2") + "\r\n");
						}
					} else{
						text.append("Error during request \r\n");
					}
					 
				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					System.out.println("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during GetPushMessages \r\n");
				}
			}
		});
		
		btnGetPushMessages.setBounds(10, 72, 172, 25);
		btnGetPushMessages.setText("Get Push Messages");
		
		btnGetPushMessagesByDevice = new Button(shlSampleForm, SWT.NONE);
		
		btnGetPushMessagesByDevice.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				
				Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca = new CoreApi(ConfigClass.AppId, cr);
				
				PushipUtil.SetTimeZone("Europe/Rome");
				
				try {

					HashMap<String, Object> map = new HashMap<String, Object>();
					map.put("DeviceId", "jS0oE8PtHcVerde_7a6ff0f023039299"); //Device ID filter 
					map.put("Limit", "10");
					map.put("Offset", "0");
					map.put("IncludeParams", "True");

					JSONArray al = ca.GetPushMessagesByDevice(map);
					
					text.append("\r\nGet Push Messages By Device \r\n");
					if (al != null) {
						for (int i = 0; i < al.length(); i++) {
							text.append(al.getJSONObject(i).get("PushMessageId") + "\r\n");
							text.append(al.getJSONObject(i).get("Message") + "\r\n");

							String date = al.getJSONObject(i).getString("Date");
							text.append(PushipUtil.ParseDate(date) + "\r\n");

							text.append(al.getJSONObject(i).getJSONObject("Params").get("Param1") + "\r\n");
							text.append(al.getJSONObject(i).getJSONObject("Params").get("Param2") + "\r\n");
						}
					} else {
						text.append("Error during request \r\n");
					}

				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during GetPushMessagesByDevice \r\n");
				}
			}
		});
		
		btnGetPushMessagesByDevice.setBounds(10, 103, 172, 25);
		btnGetPushMessagesByDevice.setText("Get Push Messages By Device");
		
		btnDeletePushMessage = new Button(shlSampleForm, SWT.NONE);
		
		btnDeletePushMessage.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				
				Credentials cr = new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca = new CoreApi(ConfigClass.AppId, cr);

				try {

					HashMap<String, Object> map = new HashMap<String, Object>();
					map.put("PushMessageId", "jS0oE8PtHcVerde_635381772129500000");

					JSONObject al = ca.DeletePushMessage(map);
					
					text.append("\r\nDelete Push Messages \r\n");
					if (al != null) {
							text.append(al.get("Error") + "\r\n");
							text.append(al.get("Message") + "\r\n");

					} else {
						text.append("Error during request \r\n");
					}

				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				} 
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during DeletePushMessage \r\n");
				}
			}
		});
		
		btnDeletePushMessage.setBounds(10, 134, 172, 25);
		btnDeletePushMessage.setText("Delete Push Message");
		
		btnSendPushMessage = new Button(shlSampleForm, SWT.NONE);
		
		btnSendPushMessage.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				Credentials cr= new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca= new CoreApi(ConfigClass.AppId,cr);
				
				try {
					
					HashMap<String, Object> map=  new HashMap<String, Object>();
					map.put("Message", "Push message from java to all android Libra test");
					//map.put("Badge", "1");
					map.put("Push", "False");
					//map.put("Sound", "Default");
					
					map.put("SendIOS", "False");
					map.put("SendAndroid", "False");
					map.put("SendBB", "False");
					map.put("SendWP", "True");	//push sent to WindowsPhone devices

					
					
				/*	map.put("P1Latitude", "40.42163694648697");
					map.put("P1Longitude", "10.299156188964844");
					map.put("P2Latitude", "47.45030563100575");
					map.put("P2Longitude", "15.368927001953125");*/
					
					
					Calendar c = Calendar.getInstance();
					c.set(2014, 5, 6, 0, 0,0); // June, 07, 2014
					
					//map.put("LastPositionDate", c.getTime());
					//map.put("LastPositionNumber", "5"); 
					
					
					Set<String> tags = new HashSet<String>();
					tags.add("Libra");
					
					map.put("Tags", tags);
					

					HashMap<String, Object> params=  new HashMap<String, Object>();
					params.put("Param1", "Param number 1");
					params.put("Param2", "ttps://www.facebook.com/OfficialPuship");
					params.put("Param3", "index.html");
					params.put("Param4", "122.45");
					params.put("Param5", "Special chars:  '%1234567890\"!$%&/()=?^@#-,'"); //max 5 params
					
					map.put("Params", params);
					
					JSONObject al= ca.SendPushMessage(map);
					
					text.append("\r\nSend Push Messages \r\n");
					if (al!=null){
						text.append(al.get("Error") + "\r\n");
						text.append(al.get("Message") + "\r\n");
					} else{
						text.append("Error during request \r\n");
					}
					
					 
				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during SendPushMessages \r\n");
				}
			}
		});
		
		btnSendPushMessage.setBounds(10, 165, 172, 25);
		btnSendPushMessage.setText("Send Push Message");
		
		btnSendPushMessageByDevice = new Button(shlSampleForm, SWT.NONE);
		
		btnSendPushMessageByDevice.addSelectionListener(new SelectionAdapter() {
			
			@Override
			public void widgetSelected(SelectionEvent e) {
				
				Credentials cr= new Credentials(ConfigClass.Username, ConfigClass.Password);
				CoreApi ca= new CoreApi(ConfigClass.AppId,cr);
				
				try {
					
					HashMap<String, Object> map=  new HashMap<String, Object>();
					map.put("Message", "Push message to android from java");
					map.put("Badge", "2");
					map.put("Push", "False");
					map.put("Sound", "Default");
					
					Set<String> devicetosend = new HashSet<String>();
					devicetosend.add("jS0oE8PtHcVerde_7a6ff0f023039299"); //push sent to Android device
					
					map.put("Devices", devicetosend);
					

					HashMap<String, Object> params=  new HashMap<String, Object>();
					params.put("Param1", "Param number 1");
					params.put("Param2", "ttps://www.facebook.com/OfficialPuship");
					params.put("Param3", "index.html");
					params.put("Param4", "122.45");
					params.put("Param5", "Special chars:  '%1234567890\"!$%&/()=?^@#-,'"); //max 5 params
					
					map.put("Params", params);
					
					JSONObject al= ca.SendPushMessageByDevice(map);
					
					text.append("\r\nSend Push Messages By Device \r\n");
					if (al!=null){
						text.append(al.get("Error") + "\r\n");
						text.append(al.get("Message") + "\r\n");
					} else{
						text.append("Error during request \r\n");
					}
					
				}catch (UnknownHostException httpe) {
					httpe.printStackTrace();
					text.append("Error during URL request: probably no connection or wrong URL \r\n");
				}
				catch (Exception ex) {
					ex.printStackTrace();
					text.append("Error during SendPushMessageByDevice \r\n");
				}
			}
		});
		
		btnSendPushMessageByDevice.setBounds(10, 196, 172, 25);
		btnSendPushMessageByDevice.setText("Send Push Message By Device \r\n");
		
		Button btnClear = new Button(shlSampleForm, SWT.NONE);
		btnClear.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				text.setText("");
			}
		});
		btnClear.setBounds(10, 442, 172, 48);
		btnClear.setText("CLEAR ALL");

	}
}
